@@ -1,3 +1,4 @@
+from collections.abc import Sequence
 from typing import Literal
 
 from pydantic import Field, HttpUrl, PostgresDsn, RedisDsn, SecretStr, model_validator
@@ -13,9 +14,14 @@ class CommonSettings(BaseSettings):
 class OIDCSettings(BaseSettings):
     model_config = SettingsConfigDict(env_prefix='OIDC_')
 
-    enabled: bool = True
     authority_url: HttpUrl | None = None
     client_id: str | None = None
+    redirect_uri: str | None = None
+    scopes: Sequence[str] = (
+        'openid',
+        'profile',
+        'email',
+    )
 
 
 class ValkeySettings(BaseSettings):
@@ -28,7 +34,7 @@ class ValkeySettings(BaseSettings):
 class DBSettings(BaseSettings):
     model_config = SettingsConfigDict(env_prefix='DB_', validate_by_name=True, validate_by_alias=True)
 
-    dsn: PostgresDsn | None = None
+    dsn: PostgresDsn | str | None = None
     scheme: str = 'postgresql+asyncpg'
     host: str = 'localhost'
     port: int = 5432
@@ -43,7 +49,7 @@ class DBSettings(BaseSettings):
     pool_recycle: int = 1800  # 30 minutes
 
     @model_validator(mode='after')
-    def build_dsn_if_missing(self) -> 'DBSettings':
+    def build_dsn_if_missing(self) -> DBSettings:
         if self.dsn is None and all(
             (
                 self.user,
